Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(187)

Unified Diff: vm/parser.cc

Issue 10375059: Use a reserved stack local variable to store the Code object so that it can be looked up easily whe… (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/runtime/
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « vm/parser.h ('k') | vm/raw_object.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: vm/parser.cc
===================================================================
--- vm/parser.cc (revision 7669)
+++ vm/parser.cc (working copy)
@@ -146,15 +146,15 @@
// parameters to copy.
if (optional_parameter_count == 0) {
// Parameter i will be at fp[1 + parameter_count - i] and local variable
- // j will be at fp[-1 - j].
+ // j will be at fp[kFirstLocalSlotIndex - j].
first_parameter_index_ = 1 + parameter_count;
- first_stack_local_index_ = -1;
+ first_stack_local_index_ = kFirstLocalSlotIndex;
copied_parameter_count_ = 0;
} else {
- // Parameter i will be at fp[-1 - i] and local variable j will be at
- // fp[-1 - parameter_count - j].
- first_parameter_index_ = -1;
- first_stack_local_index_ = -1 - parameter_count;
+ // Parameter i will be at fp[kFirstLocalSlotIndex - i] and local variable
+ // j will be at fp[kFirstLocalSlotIndex - parameter_count - j].
+ first_parameter_index_ = kFirstLocalSlotIndex;
+ first_stack_local_index_ = first_parameter_index_ - parameter_count;
copied_parameter_count_ = parameter_count;
}
« no previous file with comments | « vm/parser.h ('k') | vm/raw_object.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698